@@ -23,7 +23,7 @@ extern "C" {
 #endif
 
 GRN_API grn_rc grn_dump_table_create_flags(grn_ctx *ctx,
-                                           grn_obj_flags flags,
+                                           grn_table_flags flags,
                                            grn_obj *buffer);
 GRN_API grn_rc grn_dump_column_create_flags(grn_ctx *ctx,
                                             grn_obj_flags flags,
