@@ -170,12 +170,21 @@ grn_plugin_call_init(grn_ctx *ctx, grn_id id)
 static grn_rc
 grn_plugin_call_register_mrb(grn_ctx *ctx, grn_id id, grn_plugin *plugin)
 {
-  grn_mrb_data *data = &(ctx->impl->mrb);
-  mrb_state *mrb = data->state;
-  struct RClass *module = data->module;
+  grn_mrb_data *data;
+  mrb_state *mrb;
+  struct RClass *module;
   struct RClass *plugin_loader_class;
   int arena_index;
 
+  grn_ctx_impl_mrb_ensure_init(ctx);
+  if (ctx->rc != GRN_SUCCESS) {
+    return ctx->rc;
+  }
+
+  data = &(ctx->impl->mrb);
+  mrb = data->state;
+  module = data->module;
+
   {
     int added;
     grn_hash_add(ctx, ctx->impl->mrb.registered_plugins,
@@ -895,9 +904,7 @@ grn_plugin_ensure_registered(grn_ctx *ctx, grn_obj *proc)
   CRITICAL_SECTION_ENTER(grn_plugins_lock);
   {
     const char *value;
-    uint32_t value_size;
-    value = grn_hash_get_value_(&grn_plugins_ctx, grn_plugins, plugin_id,
-                                &value_size);
+    value = grn_hash_get_value_(&grn_plugins_ctx, grn_plugins, plugin_id, NULL);
     if (value) {
       plugin = *((grn_plugin **)value);
     }
@@ -1081,33 +1088,46 @@ grn_plugin_free(grn_ctx *ctx, void *ptr, const char *file, int line,
   grn_free(ctx, ptr, file, line, func);
 }
 
-/*
-  grn_plugin_ctx_log() is a clone of grn_ctx_log() in ctx.c. The only
-  difference is that grn_plugin_ctx_log() uses va_list instead of `...'.
- */
-static void
-grn_plugin_ctx_log(grn_ctx *ctx, const char *format, va_list ap)
-{
-  vsnprintf(ctx->errbuf, GRN_CTX_MSGSIZE, format, ap);
-}
-
 void
 grn_plugin_set_error(grn_ctx *ctx, grn_log_level level, grn_rc error_code,
                      const char *file, int line, const char *func,
                      const char *format, ...)
 {
+  char old_error_message[GRN_CTX_MSGSIZE];
+
   ctx->errlvl = level;
   ctx->rc = error_code;
   ctx->errfile = file;
   ctx->errline = line;
   ctx->errfunc = func;
 
+  grn_strcpy(old_error_message, GRN_CTX_MSGSIZE, ctx->errbuf);
+
   {
     va_list ap;
     va_start(ap, format);
-    grn_plugin_ctx_log(ctx, format, ap);
+    grn_ctx_logv(ctx, format, ap);
     va_end(ap);
   }
+
+  if (grn_ctx_impl_should_log(ctx)) {
+    grn_ctx_impl_set_current_error_message(ctx);
+    if (grn_logger_pass(ctx, level)) {
+      char new_error_message[GRN_CTX_MSGSIZE];
+      grn_strcpy(new_error_message, GRN_CTX_MSGSIZE, ctx->errbuf);
+      grn_strcpy(ctx->errbuf, GRN_CTX_MSGSIZE, old_error_message);
+      {
+        va_list ap;
+        va_start(ap, format);
+        grn_logger_putv(ctx, level, file, line, func, format, ap);
+        va_end(ap);
+      }
+      grn_strcpy(ctx->errbuf, GRN_CTX_MSGSIZE, new_error_message);
+    }
+    if (level <= GRN_LOG_ERROR) {
+      grn_plugin_logtrace(ctx, level);
+    }
+  }
 }
 
 void
@@ -1126,6 +1146,7 @@ void
 grn_plugin_logtrace(grn_ctx *ctx, grn_log_level level)
 {
   if (level <= GRN_LOG_ERROR) {
+    grn_plugin_backtrace(ctx);
     LOGTRACE(ctx, level);
   }
 }
@@ -1184,7 +1205,7 @@ grn_plugin_mutex_unlock(grn_ctx *ctx, grn_plugin_mutex *mutex)
 
 grn_obj *
 grn_plugin_proc_alloc(grn_ctx *ctx, grn_user_data *user_data,
-                      grn_id domain, grn_obj_flags flags)
+                      grn_id domain, unsigned char flags)
 {
   return grn_proc_alloc(ctx, user_data, domain, flags);
 }
